from ...tl.mtproto_request import MTProtoRequest


class UpdateBotInlineQuery(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateBotInlineQuery#54826690 flags:# query_id:long user_id:int query:string geo:flags.0?GeoPoint offset:string = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x54826690

    def __init__(self, query_id, user_id, query, offset, geo=None):
        """
        :param query_id: Telegram type: «long».
        :param user_id: Telegram type: «int».
        :param query: Telegram type: «string».
        :param geo: Telegram type: «GeoPoint».
        :param offset: Telegram type: «string».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.query_id = query_id
        self.user_id = user_id
        self.query = query
        self.geo = geo
        self.offset = offset

    def on_send(self, writer):
        writer.write_int(UpdateBotInlineQuery.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.geo else 0
        writer.write_int(flags)

        writer.write_long(self.query_id)
        writer.write_int(self.user_id)
        writer.tgwrite_string(self.query)
        if self.geo:
            self.geo.on_send(writer)

        writer.tgwrite_string(self.offset)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateBotInlineQuery(None, None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        self.query_id = reader.read_long()
        self.user_id = reader.read_int()
        self.query = reader.tgread_string()
        if (flags & (1 << 0)) != 0:
            self.geo = reader.tgread_object()

        self.offset = reader.tgread_string()

    def __repr__(self):
        return 'updateBotInlineQuery#54826690 flags:# query_id:long user_id:int query:string geo:flags.0?GeoPoint offset:string = Update'

    def __str__(self):
        return '(updateBotInlineQuery (ID: 0x54826690) = (query_id={}, user_id={}, query={}, geo={}, offset={}))'.format(str(self.query_id), str(self.user_id), str(self.query), str(self.geo), str(self.offset))



from ....tl.mtproto_request import MTProtoRequest


class FeaturedStickers(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.featuredStickers#f89d88e5 hash:int sets:Vector<StickerSetCovered> unread:Vector<long> = messages.FeaturedStickers"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xf89d88e5

    def __init__(self, hash, sets, unread):
        """
        :param hash: Telegram type: «int».
        :param sets: Telegram type: «StickerSetCovered». Must be a list.
        :param unread: Telegram type: «long». Must be a list.

        Constructor for messages.FeaturedStickers: Instance of either FeaturedStickersNotModified, FeaturedStickers.
        """
        super().__init__()

        self.hash = hash
        self.sets = sets
        self.unread = unread

    def on_send(self, writer):
        writer.write_int(FeaturedStickers.constructor_id, signed=False)
        writer.write_int(self.hash)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.sets))
        for sets_item in self.sets:
            sets_item.on_send(writer)

        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.unread))
        for unread_item in self.unread:
            writer.write_long(unread_item)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return FeaturedStickers(None, None, None)

    def on_response(self, reader):
        self.hash = reader.read_int()
        reader.read_int()  # Vector's constructor ID
        self.sets = []  # Initialize an empty list
        sets_len = reader.read_int()
        for _ in range(sets_len):
            sets_item = reader.tgread_object()
            self.sets.append(sets_item)

        reader.read_int()  # Vector's constructor ID
        self.unread = []  # Initialize an empty list
        unread_len = reader.read_int()
        for _ in range(unread_len):
            unread_item = reader.read_long()
            self.unread.append(unread_item)

    def __repr__(self):
        return 'messages.featuredStickers#f89d88e5 hash:int sets:Vector<StickerSetCovered> unread:Vector<long> = messages.FeaturedStickers'

    def __str__(self):
        return '(messages.featuredStickers (ID: 0xf89d88e5) = (hash={}, sets={}, unread={}))'.format(str(self.hash), None if not self.sets else [str(_) for _ in self.sets], None if not self.unread else [str(_) for _ in self.unread])



from ....tl.mtproto_request import MTProtoRequest


class RecentStickers(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.recentStickers#5ce20970 hash:int stickers:Vector<Document> = messages.RecentStickers"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x5ce20970

    def __init__(self, hash, stickers):
        """
        :param hash: Telegram type: «int».
        :param stickers: Telegram type: «Document». Must be a list.

        Constructor for messages.RecentStickers: Instance of either RecentStickersNotModified, RecentStickers.
        """
        super().__init__()

        self.hash = hash
        self.stickers = stickers

    def on_send(self, writer):
        writer.write_int(RecentStickers.constructor_id, signed=False)
        writer.write_int(self.hash)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.stickers))
        for stickers_item in self.stickers:
            stickers_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return RecentStickers(None, None)

    def on_response(self, reader):
        self.hash = reader.read_int()
        reader.read_int()  # Vector's constructor ID
        self.stickers = []  # Initialize an empty list
        stickers_len = reader.read_int()
        for _ in range(stickers_len):
            stickers_item = reader.tgread_object()
            self.stickers.append(stickers_item)

    def __repr__(self):
        return 'messages.recentStickers#5ce20970 hash:int stickers:Vector<Document> = messages.RecentStickers'

    def __str__(self):
        return '(messages.recentStickers (ID: 0x5ce20970) = (hash={}, stickers={}))'.format(str(self.hash), None if not self.stickers else [str(_) for _ in self.stickers])



from ....tl.mtproto_request import MTProtoRequest


class Authorizations(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    account.authorizations#1250abde authorizations:Vector<Authorization> = account.Authorizations"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x1250abde

    def __init__(self, authorizations):
        """
        :param authorizations: Telegram type: «Authorization». Must be a list.

        Constructor for account.Authorizations: Instance of Authorizations.
        """
        super().__init__()

        self.authorizations = authorizations

    def on_send(self, writer):
        writer.write_int(Authorizations.constructor_id, signed=False)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.authorizations))
        for authorizations_item in self.authorizations:
            authorizations_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return Authorizations(None)

    def on_response(self, reader):
        reader.read_int()  # Vector's constructor ID
        self.authorizations = []  # Initialize an empty list
        authorizations_len = reader.read_int()
        for _ in range(authorizations_len):
            authorizations_item = reader.tgread_object()
            self.authorizations.append(authorizations_item)

    def __repr__(self):
        return 'account.authorizations#1250abde authorizations:Vector<Authorization> = account.Authorizations'

    def __str__(self):
        return '(account.authorizations (ID: 0x1250abde) = (authorizations={}))'.format(None if not self.authorizations else [str(_) for _ in self.authorizations])



from ...tl.mtproto_request import MTProtoRequest


class Dialog(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    dialog#66ffba14 flags:# pinned:flags.2?true peer:Peer top_message:int read_inbox_max_id:int read_outbox_max_id:int unread_count:int notify_settings:PeerNotifySettings pts:flags.0?int draft:flags.1?DraftMessage = Dialog"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x66ffba14

    def __init__(self, peer, top_message, read_inbox_max_id, read_outbox_max_id, unread_count, notify_settings, pinned=None, pts=None, draft=None):
        """
        :param pinned: Telegram type: «true».
        :param peer: Telegram type: «Peer».
        :param top_message: Telegram type: «int».
        :param read_inbox_max_id: Telegram type: «int».
        :param read_outbox_max_id: Telegram type: «int».
        :param unread_count: Telegram type: «int».
        :param notify_settings: Telegram type: «PeerNotifySettings».
        :param pts: Telegram type: «int».
        :param draft: Telegram type: «DraftMessage».

        Constructor for Dialog: Instance of Dialog.
        """
        super().__init__()

        self.pinned = pinned
        self.peer = peer
        self.top_message = top_message
        self.read_inbox_max_id = read_inbox_max_id
        self.read_outbox_max_id = read_outbox_max_id
        self.unread_count = unread_count
        self.notify_settings = notify_settings
        self.pts = pts
        self.draft = draft

    def on_send(self, writer):
        writer.write_int(Dialog.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 2) if self.pinned else 0
        flags |= (1 << 0) if self.pts else 0
        flags |= (1 << 1) if self.draft else 0
        writer.write_int(flags)

        self.peer.on_send(writer)
        writer.write_int(self.top_message)
        writer.write_int(self.read_inbox_max_id)
        writer.write_int(self.read_outbox_max_id)
        writer.write_int(self.unread_count)
        self.notify_settings.on_send(writer)
        if self.pts:
            writer.write_int(self.pts)

        if self.draft:
            self.draft.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return Dialog(None, None, None, None, None, None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 2)) != 0:
            self.pinned = True  # Arbitrary not-None value, no need to read since it is a flag

        self.peer = reader.tgread_object()
        self.top_message = reader.read_int()
        self.read_inbox_max_id = reader.read_int()
        self.read_outbox_max_id = reader.read_int()
        self.unread_count = reader.read_int()
        self.notify_settings = reader.tgread_object()
        if (flags & (1 << 0)) != 0:
            self.pts = reader.read_int()

        if (flags & (1 << 1)) != 0:
            self.draft = reader.tgread_object()

    def __repr__(self):
        return 'dialog#66ffba14 flags:# pinned:flags.2?true peer:Peer top_message:int read_inbox_max_id:int read_outbox_max_id:int unread_count:int notify_settings:PeerNotifySettings pts:flags.0?int draft:flags.1?DraftMessage = Dialog'

    def __str__(self):
        return '(dialog (ID: 0x66ffba14) = (pinned={}, peer={}, top_message={}, read_inbox_max_id={}, read_outbox_max_id={}, unread_count={}, notify_settings={}, pts={}, draft={}))'.format(str(self.pinned), str(self.peer), str(self.top_message), str(self.read_inbox_max_id), str(self.read_outbox_max_id), str(self.unread_count), str(self.notify_settings), str(self.pts), str(self.draft))



from ...tl.mtproto_request import MTProtoRequest


class UpdateChannelTooLong(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateChannelTooLong#eb0467fb flags:# channel_id:int pts:flags.0?int = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xeb0467fb

    def __init__(self, channel_id, pts=None):
        """
        :param channel_id: Telegram type: «int».
        :param pts: Telegram type: «int».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.channel_id = channel_id
        self.pts = pts

    def on_send(self, writer):
        writer.write_int(UpdateChannelTooLong.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.pts else 0
        writer.write_int(flags)

        writer.write_int(self.channel_id)
        if self.pts:
            writer.write_int(self.pts)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateChannelTooLong(None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        self.channel_id = reader.read_int()
        if (flags & (1 << 0)) != 0:
            self.pts = reader.read_int()

    def __repr__(self):
        return 'updateChannelTooLong#eb0467fb flags:# channel_id:int pts:flags.0?int = Update'

    def __str__(self):
        return '(updateChannelTooLong (ID: 0xeb0467fb) = (channel_id={}, pts={}))'.format(str(self.channel_id), str(self.pts))



from ....tl.mtproto_request import MTProtoRequest


class BotCallbackAnswer(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.botCallbackAnswer#36585ea4 flags:# alert:flags.1?true has_url:flags.3?true message:flags.0?string url:flags.2?string cache_time:int = messages.BotCallbackAnswer"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x36585ea4

    def __init__(self, cache_time, alert=None, has_url=None, message=None, url=None):
        """
        :param alert: Telegram type: «true».
        :param has_url: Telegram type: «true».
        :param message: Telegram type: «string».
        :param url: Telegram type: «string».
        :param cache_time: Telegram type: «int».

        Constructor for messages.BotCallbackAnswer: Instance of BotCallbackAnswer.
        """
        super().__init__()

        self.alert = alert
        self.has_url = has_url
        self.message = message
        self.url = url
        self.cache_time = cache_time

    def on_send(self, writer):
        writer.write_int(BotCallbackAnswer.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 1) if self.alert else 0
        flags |= (1 << 3) if self.has_url else 0
        flags |= (1 << 0) if self.message else 0
        flags |= (1 << 2) if self.url else 0
        writer.write_int(flags)

        if self.message:
            writer.tgwrite_string(self.message)

        if self.url:
            writer.tgwrite_string(self.url)

        writer.write_int(self.cache_time)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return BotCallbackAnswer(None, None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 1)) != 0:
            self.alert = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 3)) != 0:
            self.has_url = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 0)) != 0:
            self.message = reader.tgread_string()

        if (flags & (1 << 2)) != 0:
            self.url = reader.tgread_string()

        self.cache_time = reader.read_int()

    def __repr__(self):
        return 'messages.botCallbackAnswer#36585ea4 flags:# alert:flags.1?true has_url:flags.3?true message:flags.0?string url:flags.2?string cache_time:int = messages.BotCallbackAnswer'

    def __str__(self):
        return '(messages.botCallbackAnswer (ID: 0x36585ea4) = (alert={}, has_url={}, message={}, url={}, cache_time={}))'.format(str(self.alert), str(self.has_url), str(self.message), str(self.url), str(self.cache_time))



from ...tl.mtproto_request import MTProtoRequest


class DestroySessionNone(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    destroy_session_none#62d350c9 session_id:long = DestroySessionRes"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x62d350c9

    def __init__(self, session_id):
        """
        :param session_id: Telegram type: «long».

        Constructor for DestroySessionRes: Instance of either DestroySessionOk, DestroySessionNone.
        """
        super().__init__()

        self.session_id = session_id

    def on_send(self, writer):
        writer.write_int(DestroySessionNone.constructor_id, signed=False)
        writer.write_long(self.session_id)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return DestroySessionNone(None)

    def on_response(self, reader):
        self.session_id = reader.read_long()

    def __repr__(self):
        return 'destroy_session_none#62d350c9 session_id:long = DestroySessionRes'

    def __str__(self):
        return '(destroy_session_none (ID: 0x62d350c9) = (session_id={}))'.format(str(self.session_id))



from ...tl.mtproto_request import MTProtoRequest


class UpdateBotPrecheckoutQuery(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateBotPrecheckoutQuery#5d2f3aa9 flags:# query_id:long user_id:int payload:bytes info:flags.0?PaymentRequestedInfo shipping_option_id:flags.1?string currency:string total_amount:long = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x5d2f3aa9

    def __init__(self, query_id, user_id, payload, currency, total_amount, info=None, shipping_option_id=None):
        """
        :param query_id: Telegram type: «long».
        :param user_id: Telegram type: «int».
        :param payload: Telegram type: «bytes».
        :param info: Telegram type: «PaymentRequestedInfo».
        :param shipping_option_id: Telegram type: «string».
        :param currency: Telegram type: «string».
        :param total_amount: Telegram type: «long».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.query_id = query_id
        self.user_id = user_id
        self.payload = payload
        self.info = info
        self.shipping_option_id = shipping_option_id
        self.currency = currency
        self.total_amount = total_amount

    def on_send(self, writer):
        writer.write_int(UpdateBotPrecheckoutQuery.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.info else 0
        flags |= (1 << 1) if self.shipping_option_id else 0
        writer.write_int(flags)

        writer.write_long(self.query_id)
        writer.write_int(self.user_id)
        writer.tgwrite_bytes(self.payload)
        if self.info:
            self.info.on_send(writer)

        if self.shipping_option_id:
            writer.tgwrite_string(self.shipping_option_id)

        writer.tgwrite_string(self.currency)
        writer.write_long(self.total_amount)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateBotPrecheckoutQuery(None, None, None, None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        self.query_id = reader.read_long()
        self.user_id = reader.read_int()
        self.payload = reader.tgread_bytes()
        if (flags & (1 << 0)) != 0:
            self.info = reader.tgread_object()

        if (flags & (1 << 1)) != 0:
            self.shipping_option_id = reader.tgread_string()

        self.currency = reader.tgread_string()
        self.total_amount = reader.read_long()

    def __repr__(self):
        return 'updateBotPrecheckoutQuery#5d2f3aa9 flags:# query_id:long user_id:int payload:bytes info:flags.0?PaymentRequestedInfo shipping_option_id:flags.1?string currency:string total_amount:long = Update'

    def __str__(self):
        return '(updateBotPrecheckoutQuery (ID: 0x5d2f3aa9) = (query_id={}, user_id={}, payload={}, info={}, shipping_option_id={}, currency={}, total_amount={}))'.format(str(self.query_id), str(self.user_id), str(self.payload), str(self.info), str(self.shipping_option_id), str(self.currency), str(self.total_amount))



from ...tl.mtproto_request import MTProtoRequest


class MessageActionPaymentSentMe(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messageActionPaymentSentMe#8f31b327 flags:# currency:string total_amount:long payload:bytes info:flags.0?PaymentRequestedInfo shipping_option_id:flags.1?string charge:PaymentCharge = MessageAction"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x8f31b327

    def __init__(self, currency, total_amount, payload, charge, info=None, shipping_option_id=None):
        """
        :param currency: Telegram type: «string».
        :param total_amount: Telegram type: «long».
        :param payload: Telegram type: «bytes».
        :param info: Telegram type: «PaymentRequestedInfo».
        :param shipping_option_id: Telegram type: «string».
        :param charge: Telegram type: «PaymentCharge».

        Constructor for MessageAction: Instance of either MessageActionEmpty, MessageActionChatCreate, MessageActionChatEditTitle, MessageActionChatEditPhoto, MessageActionChatDeletePhoto, MessageActionChatAddUser, MessageActionChatDeleteUser, MessageActionChatJoinedByLink, MessageActionChannelCreate, MessageActionChatMigrateTo, MessageActionChannelMigrateFrom, MessageActionPinMessage, MessageActionHistoryClear, MessageActionGameScore, MessageActionPaymentSentMe, MessageActionPaymentSent, MessageActionPhoneCall.
        """
        super().__init__()

        self.currency = currency
        self.total_amount = total_amount
        self.payload = payload
        self.info = info
        self.shipping_option_id = shipping_option_id
        self.charge = charge

    def on_send(self, writer):
        writer.write_int(MessageActionPaymentSentMe.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.info else 0
        flags |= (1 << 1) if self.shipping_option_id else 0
        writer.write_int(flags)

        writer.tgwrite_string(self.currency)
        writer.write_long(self.total_amount)
        writer.tgwrite_bytes(self.payload)
        if self.info:
            self.info.on_send(writer)

        if self.shipping_option_id:
            writer.tgwrite_string(self.shipping_option_id)

        self.charge.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return MessageActionPaymentSentMe(None, None, None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        self.currency = reader.tgread_string()
        self.total_amount = reader.read_long()
        self.payload = reader.tgread_bytes()
        if (flags & (1 << 0)) != 0:
            self.info = reader.tgread_object()

        if (flags & (1 << 1)) != 0:
            self.shipping_option_id = reader.tgread_string()

        self.charge = reader.tgread_object()

    def __repr__(self):
        return 'messageActionPaymentSentMe#8f31b327 flags:# currency:string total_amount:long payload:bytes info:flags.0?PaymentRequestedInfo shipping_option_id:flags.1?string charge:PaymentCharge = MessageAction'

    def __str__(self):
        return '(messageActionPaymentSentMe (ID: 0x8f31b327) = (currency={}, total_amount={}, payload={}, info={}, shipping_option_id={}, charge={}))'.format(str(self.currency), str(self.total_amount), str(self.payload), str(self.info), str(self.shipping_option_id), str(self.charge))



from ....tl.mtproto_request import MTProtoRequest


class AnswerWebhookJSONQueryRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    bots.answerWebhookJSONQuery#e6213f4d query_id:long data:DataJSON = Bool"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xe6213f4d

    def __init__(self, query_id, data):
        """
        :param query_id: Telegram type: «long».
        :param data: Telegram type: «DataJSON».

        :returns Bool: This type has no constructors.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.query_id = query_id
        self.data = data

    def on_send(self, writer):
        writer.write_int(AnswerWebhookJSONQueryRequest.constructor_id, signed=False)
        writer.write_long(self.query_id)
        self.data.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return AnswerWebhookJSONQueryRequest(None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'bots.answerWebhookJSONQuery#e6213f4d query_id:long data:DataJSON = Bool'

    def __str__(self):
        return '(bots.answerWebhookJSONQuery (ID: 0xe6213f4d) = (query_id={}, data={}))'.format(str(self.query_id), str(self.data))



from ....tl.mtproto_request import MTProtoRequest


class SearchGlobalRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.searchGlobal#9e3cacb0 q:string offset_date:date offset_peer:InputPeer offset_id:int limit:int = messages.Messages"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x9e3cacb0

    def __init__(self, q, offset_date, offset_peer, offset_id, limit):
        """
        :param q: Telegram type: «string».
        :param offset_date: Telegram type: «date».
        :param offset_peer: Telegram type: «InputPeer».
        :param offset_id: Telegram type: «int».
        :param limit: Telegram type: «int».

        :returns messages.Messages: Instance of either Messages, MessagesSlice, ChannelMessages.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.q = q
        self.offset_date = offset_date
        self.offset_peer = offset_peer
        self.offset_id = offset_id
        self.limit = limit

    def on_send(self, writer):
        writer.write_int(SearchGlobalRequest.constructor_id, signed=False)
        writer.tgwrite_string(self.q)
        writer.tgwrite_date(self.offset_date)
        self.offset_peer.on_send(writer)
        writer.write_int(self.offset_id)
        writer.write_int(self.limit)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return SearchGlobalRequest(None, None, None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.searchGlobal#9e3cacb0 q:string offset_date:date offset_peer:InputPeer offset_id:int limit:int = messages.Messages'

    def __str__(self):
        return '(messages.searchGlobal (ID: 0x9e3cacb0) = (q={}, offset_date={}, offset_peer={}, offset_id={}, limit={}))'.format(str(self.q), str(self.offset_date), str(self.offset_peer), str(self.offset_id), str(self.limit))



from ...tl.mtproto_request import MTProtoRequest


class UpdateReadChannelInbox(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateReadChannelInbox#4214f37f channel_id:int max_id:int = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x4214f37f

    def __init__(self, channel_id, max_id):
        """
        :param channel_id: Telegram type: «int».
        :param max_id: Telegram type: «int».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.channel_id = channel_id
        self.max_id = max_id

    def on_send(self, writer):
        writer.write_int(UpdateReadChannelInbox.constructor_id, signed=False)
        writer.write_int(self.channel_id)
        writer.write_int(self.max_id)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateReadChannelInbox(None, None)

    def on_response(self, reader):
        self.channel_id = reader.read_int()
        self.max_id = reader.read_int()

    def __repr__(self):
        return 'updateReadChannelInbox#4214f37f channel_id:int max_id:int = Update'

    def __str__(self):
        return '(updateReadChannelInbox (ID: 0x4214f37f) = (channel_id={}, max_id={}))'.format(str(self.channel_id), str(self.max_id))



from .get_payment_form import GetPaymentFormRequest
from .get_payment_receipt import GetPaymentReceiptRequest
from .validate_requested_info import ValidateRequestedInfoRequest
from .send_payment_form import SendPaymentFormRequest
from .get_saved_info import GetSavedInfoRequest
from .clear_saved_info import ClearSavedInfoRequest



from ...tl.mtproto_request import MTProtoRequest


class ChatInviteExported(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    chatInviteExported#fc2e05bc link:string = ExportedChatInvite"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xfc2e05bc

    def __init__(self, link):
        """
        :param link: Telegram type: «string».

        Constructor for ExportedChatInvite: Instance of either ChatInviteEmpty, ChatInviteExported.
        """
        super().__init__()

        self.link = link

    def on_send(self, writer):
        writer.write_int(ChatInviteExported.constructor_id, signed=False)
        writer.tgwrite_string(self.link)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ChatInviteExported(None)

    def on_response(self, reader):
        self.link = reader.tgread_string()

    def __repr__(self):
        return 'chatInviteExported#fc2e05bc link:string = ExportedChatInvite'

    def __str__(self):
        return '(chatInviteExported (ID: 0xfc2e05bc) = (link={}))'.format(str(self.link))



from ...tl.mtproto_request import MTProtoRequest


class UpdateReadChannelOutbox(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateReadChannelOutbox#25d6c9c7 channel_id:int max_id:int = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x25d6c9c7

    def __init__(self, channel_id, max_id):
        """
        :param channel_id: Telegram type: «int».
        :param max_id: Telegram type: «int».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.channel_id = channel_id
        self.max_id = max_id

    def on_send(self, writer):
        writer.write_int(UpdateReadChannelOutbox.constructor_id, signed=False)
        writer.write_int(self.channel_id)
        writer.write_int(self.max_id)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateReadChannelOutbox(None, None)

    def on_response(self, reader):
        self.channel_id = reader.read_int()
        self.max_id = reader.read_int()

    def __repr__(self):
        return 'updateReadChannelOutbox#25d6c9c7 channel_id:int max_id:int = Update'

    def __str__(self):
        return '(updateReadChannelOutbox (ID: 0x25d6c9c7) = (channel_id={}, max_id={}))'.format(str(self.channel_id), str(self.max_id))



from ...tl.mtproto_request import MTProtoRequest


class ImportedContact(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    importedContact#d0028438 user_id:int client_id:long = ImportedContact"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xd0028438

    def __init__(self, user_id, client_id):
        """
        :param user_id: Telegram type: «int».
        :param client_id: Telegram type: «long».

        Constructor for ImportedContact: Instance of ImportedContact.
        """
        super().__init__()

        self.user_id = user_id
        self.client_id = client_id

    def on_send(self, writer):
        writer.write_int(ImportedContact.constructor_id, signed=False)
        writer.write_int(self.user_id)
        writer.write_long(self.client_id)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ImportedContact(None, None)

    def on_response(self, reader):
        self.user_id = reader.read_int()
        self.client_id = reader.read_long()

    def __repr__(self):
        return 'importedContact#d0028438 user_id:int client_id:long = ImportedContact'

    def __str__(self):
        return '(importedContact (ID: 0xd0028438) = (user_id={}, client_id={}))'.format(str(self.user_id), str(self.client_id))



from ....tl.mtproto_request import MTProtoRequest


class SentCodeTypeFlashCall(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    auth.sentCodeTypeFlashCall#ab03c6d9 pattern:string = auth.SentCodeType"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xab03c6d9

    def __init__(self, pattern):
        """
        :param pattern: Telegram type: «string».

        Constructor for auth.SentCodeType: Instance of either SentCodeTypeApp, SentCodeTypeSms, SentCodeTypeCall, SentCodeTypeFlashCall.
        """
        super().__init__()

        self.pattern = pattern

    def on_send(self, writer):
        writer.write_int(SentCodeTypeFlashCall.constructor_id, signed=False)
        writer.tgwrite_string(self.pattern)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return SentCodeTypeFlashCall(None)

    def on_response(self, reader):
        self.pattern = reader.tgread_string()

    def __repr__(self):
        return 'auth.sentCodeTypeFlashCall#ab03c6d9 pattern:string = auth.SentCodeType'

    def __str__(self):
        return '(auth.sentCodeTypeFlashCall (ID: 0xab03c6d9) = (pattern={}))'.format(str(self.pattern))



from .payment_form import PaymentForm
from .validated_requested_info import ValidatedRequestedInfo
from .payment_result import PaymentResult
from .payment_verfication_needed import PaymentVerficationNeeded
from .payment_receipt import PaymentReceipt
from .saved_info import SavedInfo



from ...tl.mtproto_request import MTProtoRequest


class UpdateWebPage(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateWebPage#7f891213 webpage:WebPage pts:int pts_count:int = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x7f891213

    def __init__(self, webpage, pts, pts_count):
        """
        :param webpage: Telegram type: «WebPage».
        :param pts: Telegram type: «int».
        :param pts_count: Telegram type: «int».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.webpage = webpage
        self.pts = pts
        self.pts_count = pts_count

    def on_send(self, writer):
        writer.write_int(UpdateWebPage.constructor_id, signed=False)
        self.webpage.on_send(writer)
        writer.write_int(self.pts)
        writer.write_int(self.pts_count)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateWebPage(None, None, None)

    def on_response(self, reader):
        self.webpage = reader.tgread_object()
        self.pts = reader.read_int()
        self.pts_count = reader.read_int()

    def __repr__(self):
        return 'updateWebPage#7f891213 webpage:WebPage pts:int pts_count:int = Update'

    def __str__(self):
        return '(updateWebPage (ID: 0x7f891213) = (webpage={}, pts={}, pts_count={}))'.format(str(self.webpage), str(self.pts), str(self.pts_count))



from ....tl.mtproto_request import MTProtoRequest


class PaymentResult(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    payments.paymentResult#4e5f810d updates:Updates = payments.PaymentResult"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x4e5f810d

    def __init__(self, updates):
        """
        :param updates: Telegram type: «Updates».

        Constructor for payments.PaymentResult: Instance of either PaymentResult, PaymentVerficationNeeded.
        """
        super().__init__()

        self.updates = updates

    def on_send(self, writer):
        writer.write_int(PaymentResult.constructor_id, signed=False)
        self.updates.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return PaymentResult(None)

    def on_response(self, reader):
        self.updates = reader.tgread_object()

    def __repr__(self):
        return 'payments.paymentResult#4e5f810d updates:Updates = payments.PaymentResult'

    def __str__(self):
        return '(payments.paymentResult (ID: 0x4e5f810d) = (updates={}))'.format(str(self.updates))



from ...tl.mtproto_request import MTProtoRequest


class PhoneCallProtocol(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    phoneCallProtocol#a2bb35cb flags:# udp_p2p:flags.0?true udp_reflector:flags.1?true min_layer:int max_layer:int = PhoneCallProtocol"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xa2bb35cb

    def __init__(self, min_layer, max_layer, udp_p2p=None, udp_reflector=None):
        """
        :param udp_p2p: Telegram type: «true».
        :param udp_reflector: Telegram type: «true».
        :param min_layer: Telegram type: «int».
        :param max_layer: Telegram type: «int».

        Constructor for PhoneCallProtocol: Instance of PhoneCallProtocol.
        """
        super().__init__()

        self.udp_p2p = udp_p2p
        self.udp_reflector = udp_reflector
        self.min_layer = min_layer
        self.max_layer = max_layer

    def on_send(self, writer):
        writer.write_int(PhoneCallProtocol.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.udp_p2p else 0
        flags |= (1 << 1) if self.udp_reflector else 0
        writer.write_int(flags)

        writer.write_int(self.min_layer)
        writer.write_int(self.max_layer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return PhoneCallProtocol(None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 0)) != 0:
            self.udp_p2p = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 1)) != 0:
            self.udp_reflector = True  # Arbitrary not-None value, no need to read since it is a flag

        self.min_layer = reader.read_int()
        self.max_layer = reader.read_int()

    def __repr__(self):
        return 'phoneCallProtocol#a2bb35cb flags:# udp_p2p:flags.0?true udp_reflector:flags.1?true min_layer:int max_layer:int = PhoneCallProtocol'

    def __str__(self):
        return '(phoneCallProtocol (ID: 0xa2bb35cb) = (udp_p2p={}, udp_reflector={}, min_layer={}, max_layer={}))'.format(str(self.udp_p2p), str(self.udp_reflector), str(self.min_layer), str(self.max_layer))



from ....tl.mtproto_request import MTProtoRequest


class GetDhConfigRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.getDhConfig#26cf8950 version:int random_length:int = messages.DhConfig"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x26cf8950

    def __init__(self, version, random_length):
        """
        :param version: Telegram type: «int».
        :param random_length: Telegram type: «int».

        :returns messages.DhConfig: Instance of either DhConfigNotModified, DhConfig.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.version = version
        self.random_length = random_length

    def on_send(self, writer):
        writer.write_int(GetDhConfigRequest.constructor_id, signed=False)
        writer.write_int(self.version)
        writer.write_int(self.random_length)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return GetDhConfigRequest(None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.getDhConfig#26cf8950 version:int random_length:int = messages.DhConfig'

    def __str__(self):
        return '(messages.getDhConfig (ID: 0x26cf8950) = (version={}, random_length={}))'.format(str(self.version), str(self.random_length))



from ....tl.mtproto_request import MTProtoRequest


class ResolveUsernameRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    contacts.resolveUsername#f93ccba3 username:string = contacts.ResolvedPeer"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xf93ccba3

    def __init__(self, username):
        """
        :param username: Telegram type: «string».

        :returns contacts.ResolvedPeer: Instance of ResolvedPeer.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.username = username

    def on_send(self, writer):
        writer.write_int(ResolveUsernameRequest.constructor_id, signed=False)
        writer.tgwrite_string(self.username)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ResolveUsernameRequest(None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'contacts.resolveUsername#f93ccba3 username:string = contacts.ResolvedPeer'

    def __str__(self):
        return '(contacts.resolveUsername (ID: 0xf93ccba3) = (username={}))'.format(str(self.username))



from ....tl.mtproto_request import MTProtoRequest


class SentCodeTypeSms(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    auth.sentCodeTypeSms#c000bba2 length:int = auth.SentCodeType"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xc000bba2

    def __init__(self, length):
        """
        :param length: Telegram type: «int».

        Constructor for auth.SentCodeType: Instance of either SentCodeTypeApp, SentCodeTypeSms, SentCodeTypeCall, SentCodeTypeFlashCall.
        """
        super().__init__()

        self.length = length

    def on_send(self, writer):
        writer.write_int(SentCodeTypeSms.constructor_id, signed=False)
        writer.write_int(self.length)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return SentCodeTypeSms(None)

    def on_response(self, reader):
        self.length = reader.read_int()

    def __repr__(self):
        return 'auth.sentCodeTypeSms#c000bba2 length:int = auth.SentCodeType'

    def __str__(self):
        return '(auth.sentCodeTypeSms (ID: 0xc000bba2) = (length={}))'.format(str(self.length))



from ....tl.mtproto_request import MTProtoRequest


class SetCallRatingRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    phone.setCallRating#1c536a34 peer:InputPhoneCall rating:int comment:string = Updates"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x1c536a34

    def __init__(self, peer, rating, comment):
        """
        :param peer: Telegram type: «InputPhoneCall».
        :param rating: Telegram type: «int».
        :param comment: Telegram type: «string».

        :returns Updates: Instance of either UpdatesTooLong, UpdateShortMessage, UpdateShortChatMessage, UpdateShort, UpdatesCombined, UpdatesTg, UpdateShortSentMessage.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.peer = peer
        self.rating = rating
        self.comment = comment

    def on_send(self, writer):
        writer.write_int(SetCallRatingRequest.constructor_id, signed=False)
        self.peer.on_send(writer)
        writer.write_int(self.rating)
        writer.tgwrite_string(self.comment)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return SetCallRatingRequest(None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'phone.setCallRating#1c536a34 peer:InputPhoneCall rating:int comment:string = Updates'

    def __str__(self):
        return '(phone.setCallRating (ID: 0x1c536a34) = (peer={}, rating={}, comment={}))'.format(str(self.peer), str(self.rating), str(self.comment))



from ...tl.mtproto_request import MTProtoRequest


class BotInlineMessageMediaVenue(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    botInlineMessageMediaVenue#4366232e flags:# geo:GeoPoint title:string address:string provider:string venue_id:string reply_markup:flags.2?ReplyMarkup = BotInlineMessage"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x4366232e

    def __init__(self, geo, title, address, provider, venue_id, reply_markup=None):
        """
        :param geo: Telegram type: «GeoPoint».
        :param title: Telegram type: «string».
        :param address: Telegram type: «string».
        :param provider: Telegram type: «string».
        :param venue_id: Telegram type: «string».
        :param reply_markup: Telegram type: «ReplyMarkup».

        Constructor for BotInlineMessage: Instance of either BotInlineMessageMediaAuto, BotInlineMessageText, BotInlineMessageMediaGeo, BotInlineMessageMediaVenue, BotInlineMessageMediaContact.
        """
        super().__init__()

        self.geo = geo
        self.title = title
        self.address = address
        self.provider = provider
        self.venue_id = venue_id
        self.reply_markup = reply_markup

    def on_send(self, writer):
        writer.write_int(BotInlineMessageMediaVenue.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 2) if self.reply_markup else 0
        writer.write_int(flags)

        self.geo.on_send(writer)
        writer.tgwrite_string(self.title)
        writer.tgwrite_string(self.address)
        writer.tgwrite_string(self.provider)
        writer.tgwrite_string(self.venue_id)
        if self.reply_markup:
            self.reply_markup.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return BotInlineMessageMediaVenue(None, None, None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        self.geo = reader.tgread_object()
        self.title = reader.tgread_string()
        self.address = reader.tgread_string()
        self.provider = reader.tgread_string()
        self.venue_id = reader.tgread_string()
        if (flags & (1 << 2)) != 0:
            self.reply_markup = reader.tgread_object()

    def __repr__(self):
        return 'botInlineMessageMediaVenue#4366232e flags:# geo:GeoPoint title:string address:string provider:string venue_id:string reply_markup:flags.2?ReplyMarkup = BotInlineMessage'

    def __str__(self):
        return '(botInlineMessageMediaVenue (ID: 0x4366232e) = (geo={}, title={}, address={}, provider={}, venue_id={}, reply_markup={}))'.format(str(self.geo), str(self.title), str(self.address), str(self.provider), str(self.venue_id), str(self.reply_markup))



from ....tl.mtproto_request import MTProtoRequest


class PaymentVerficationNeeded(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    payments.paymentVerficationNeeded#6b56b921 url:string = payments.PaymentResult"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x6b56b921

    def __init__(self, url):
        """
        :param url: Telegram type: «string».

        Constructor for payments.PaymentResult: Instance of either PaymentResult, PaymentVerficationNeeded.
        """
        super().__init__()

        self.url = url

    def on_send(self, writer):
        writer.write_int(PaymentVerficationNeeded.constructor_id, signed=False)
        writer.tgwrite_string(self.url)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return PaymentVerficationNeeded(None)

    def on_response(self, reader):
        self.url = reader.tgread_string()

    def __repr__(self):
        return 'payments.paymentVerficationNeeded#6b56b921 url:string = payments.PaymentResult'

    def __str__(self):
        return '(payments.paymentVerficationNeeded (ID: 0x6b56b921) = (url={}))'.format(str(self.url))
